@@ -22,6 +22,9 @@ class Parser:
         'ARRAY': lambda args: exp.Array(expressions=args),
         'COLLECT_LIST': lambda args: exp.ArrayAgg(this=args[0]),
         'ARRAY_AGG': lambda args: exp.ArrayAgg(this=args[0]),
+        'DATE_ADD': lambda args: exp.DateAdd(this=args[0], value=args[1]),
+        'DATE_DIFF': lambda args: exp.DateDiff(this=args[0], value=args[1]),
+        'DATE_STR_TO_DATE': lambda args: exp.DateStrToDate(this=args[0]),
         'IF': lambda args: exp.If(condition=args[0], true=args[1], false=list_get(args, 2)),
         'STR_TO_TIME': lambda args: exp.StrToTime(this=args[0], format=args[1]),
         'STR_TO_UNIX': lambda args: exp.StrToUnix(this=args[0], format=args[1]),
